Struct PluginRunningInstance
pub struct PluginRunningInstance<T: GCPluginCallbackHandler> {
_plugin_interface: Box<GCPluginInterface>,
plugin_dll: PluginDLL,
startup_info: PluginInstanceStartupConfig<T>,
plugin_ctx: GCInstanceHandle,
}Expand description
Responsible for holding plugin data in memory for the duration of the plugin instance execution
Fields
_plugin_interface: Box<GCPluginInterface>plugin_dll: PluginDLLstartup_info: PluginInstanceStartupConfig<T>plugin_ctx: GCInstanceHandleImplementations
impl<T: GCPluginCallbackHandler> PluginRunningInstance<T>
impl<T: GCPluginCallbackHandler> PluginRunningInstance<T>
pub fn start(
startup_config: PluginInstanceStartupConfig<T>,
plugin_dll: PluginDLL,
) -> Result<Self, GCPluginManagerError>
pub fn start( startup_config: PluginInstanceStartupConfig<T>, plugin_dll: PluginDLL, ) -> Result<Self, GCPluginManagerError>
Starts the plugin instance by calling gc_plugin_init and passing the necessary data to the plugin.
pub fn publish_datapoint_value(
&self,
datapoint_value: GCArc<GCDatapointValue>,
) -> bool
pub fn publish_datapoint_value( &self, datapoint_value: GCArc<GCDatapointValue>, ) -> bool
Publishes a datapoint value to the plugin by calling gc_plugin_receive_datapoint
pub fn get_plugin_info(&self) -> GCPluginInfo
pub fn get_plugin_info(&self) -> GCPluginInfo
Returns the plugin info by calling gc_plugin_get_info
unsafe fn stop(&mut self)
unsafe fn stop(&mut self)